==> haskell-aeson-pretty-0.8.8-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-pretty
version:              0.8.8
visibility:           public
id:                   aeson-pretty-0.8.8-2FbbbBLCL2N9ckLNIxpIpV
key:                  aeson-pretty-0.8.8-2FbbbBLCL2N9ckLNIxpIpV
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Falko Peters <falko.peters@gmail.com>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this

    > cabal install -flib-only aeson-pretty

    the command-line tool will NOT be installed.

category:             Text, Web, JSON, Pretty Printer
abi:                  fad7ac6f01104c40c30c3e6299848068
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.0.1/site-local/aeson-pretty-0.8.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/aeson-pretty-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/aeson-pretty-0.8.8
hs-libraries:         HSaeson-pretty-0.8.8-2FbbbBLCL2N9ckLNIxpIpV
depends:
    aeson-1.5.6.0-5TyhNUN5QiGBKR8buVyIgL base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC bytestring-0.10.12.1
    scientific-0.3.7.0-85gPhyHadbV4QYqa7IGCyM text-1.2.4.1
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.8-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-pretty
version:              0.8.8
visibility:           public
id:                   aeson-pretty-0.8.8-4dcFgnpuJa6LwPAJRNk301
key:                  aeson-pretty-0.8.8-4dcFgnpuJa6LwPAJRNk301
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Falko Peters <falko.peters@gmail.com>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this

    > cabal install -flib-only aeson-pretty

    the command-line tool will NOT be installed.

category:             Text, Web, JSON, Pretty Printer
abi:                  e912e6a07d96d4edbba7a43164620cf3
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.0.1/site-local/aeson-pretty-0.8.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/aeson-pretty-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/aeson-pretty-0.8.8
hs-libraries:         HSaeson-pretty-0.8.8-4dcFgnpuJa6LwPAJRNk301
depends:
    aeson-1.5.6.0-KLnW8ZNssug7g6SUFAYcU2 base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC bytestring-0.10.12.1
    scientific-0.3.7.0-85gPhyHadbV4QYqa7IGCyM text-1.2.4.1
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
